@@ -16,7 +16,6 @@ from . mi_models import MiRecords
 from . mi_models import MiPrograms
 from . mi_models import MiProgramMetadata
 from . mi_models import MiTransactionMetadata
-from . mi_models import MiError
 
 from . mi_parser import mi_parse_execute
 from . mi_parser import mi_parse_metadata
@@ -26,8 +25,6 @@ from . mi_request import mi_request_metadata
 from . mi_request import mi_request_execute
 from . mi_request import mi_request_programs
 
-from . mi_models import Endpoint
-
 from . mi_endpoints import mi_endpoint_get
 
 
@@ -37,8 +34,18 @@ class MiApi:
         self.port = port
         self.usr = usr
         self.pwd = pwd
+        
+    @staticmethod
+    def from_env(name: str) -> 'MiApi':
+        endpoint = mi_endpoint_get(name)
+        return MiApi(
+            endpoint.host,
+            endpoint.port,
+            endpoint.usr,
+            endpoint.pwd
+        )
 
-    def execute(self, program: str, transaction: str, **kwargs) -> Union[MiRecords, MiError]:
+    def execute(self, program: str, transaction: str, **kwargs) -> MiRecords:
         return mi_parse_execute(
             mi_request_execute(
                 self.host,
@@ -51,7 +58,7 @@ class MiApi:
             ).content
         )
 
-    def program_list(self) -> Union[MiPrograms, MiError]:
+    def program_list(self) -> MiPrograms:
         return mi_parse_programs(
             mi_request_programs(
                 self.host,
@@ -61,7 +68,7 @@ class MiApi:
             ).content
         )
 
-    def program_meta(self, program: str) -> Union[MiProgramMetadata, MiError]:
+    def program_meta(self, program: str) -> MiProgramMetadata:
         return mi_parse_metadata(
             mi_request_metadata(
                 self.host,
@@ -72,12 +79,9 @@ class MiApi:
             ).content
         )
 
-    def transaction_meta(self, program: Optional[str], transaction: Optional[str]) -> Union[MiTransactionMetadata, MiError, None]:
+    def transaction_meta(self, program: str, transaction: Optional[str]) -> Union[MiTransactionMetadata, None]:
         program_meta = self.program_meta(program)
 
-        if isinstance(program_meta, MiError):
-            return program_meta
-
         for record in program_meta.transactions:
             if record.transaction == transaction:
                 return record
@@ -126,32 +130,29 @@ def mi_meta(endpoint: str, program: Optional[str] = None, transaction: Optional[
                 )
 
     elif program and transaction:
-        try:
-            return [
-                row for row in mi_parse_metadata(
-                    mi_request_metadata(
-                        mi_endpoint_get(endpoint).host,
-                        mi_endpoint_get(endpoint).port,
-                        mi_endpoint_get(endpoint).usr,
-                        mi_endpoint_get(endpoint).pwd,
-                        program
-                    ).content
-                ).transactions
-                if row.transaction == transaction
-            ][0]
-        except IndexError as error:
-            return MiError('No Results', f'{program}_{transaction} does not exist')
+        return [
+            row for row in mi_parse_metadata(
+                mi_request_metadata(
+                    mi_endpoint_get(endpoint).host,
+                    mi_endpoint_get(endpoint).port,
+                    mi_endpoint_get(endpoint).usr,
+                    mi_endpoint_get(endpoint).pwd,
+                    program
+                ).content
+            ).transactions
+            if row.transaction == transaction
+        ][0]
 
     else:
-        raise ArgumentError('No case defined for program={program} and transaction={transaction}')
+        raise RuntimeError('No case defined for program={program} and transaction={transaction}')
 
 
 def mi_api_execute(endpoint: str, program: str, transaction: str, **kwargs) -> Union[MiRecords, MiError]:
     ''' Executes API calls, either read or write depending on the transaction.
     The **kwargs represents the input values. The key word "maxrecs" is treated as a special case
-    and represents the maximum number of return records. Default is 100. Transactions that write data
-    usually don't return any value at all, so the records attribute in MiRecords will usually be
-    empty.
+    and represents the maximum number of return records. Default is 100, 0 will be all. the key word
+    "returncols" is a string with comma seperated column names, that defines which coulumns will
+    be returned.
     
     :param endpoint - The name of the endpoint
     :param program - The M3 program
