@@ -20,6 +20,13 @@ def dict_to_param_str(param_dict: dict) -> str:
     max_recs is treaded as a special case and is added in the string
     before the search parameters.
 
+    The function supports two special keywords that are treated differently.
+        1. maxrecs
+        2. returncols
+
+    maxrecs sets the number of return records (normally limited to 100 records).
+    returncols sets the columns to be returned by the api.
+
     >>> dict_to_param_str({'EDES': 'AU1'})
     '?EDES=AU1'
 
@@ -27,10 +34,14 @@ def dict_to_param_str(param_dict: dict) -> str:
     '?WHSL=AUA&ROUT=AA0001'
 
     >>> dict_to_param_str({'max_recs': 0, 'WHSL': 'AUA', 'ROUT': 'AA0001'})
-    ';max_recs=0;?WHSL=AUA&ROUT=AA0001'
+    ';maxrecs=0;?WHSL=AUA&ROUT=AA0001'
+
+    >>> dict_to_param_str({'max_rex': 10, returncols='WHLO,ITNO,EOQM', 'ITNO': 3222148800})
+    ';maxrecs=0;returncols='WHLO,ITNO,EOQM'?ITNO=3222148800'
     '''
 
     maxrecs = f';maxrecs={param_dict.pop("maxrecs")};' if param_dict.get("maxrecs") != None else ''
+    returncols = f';returncols={param_dict.pop("returncols")};' if param_dict.get("returncols") != None else ''
 
     params_str = r'&'.join(
         [
@@ -40,7 +51,7 @@ def dict_to_param_str(param_dict: dict) -> str:
         ]
     )
 
-    return f'{maxrecs}?{params_str}'
+    return f'{maxrecs}{returncols}?{params_str}'
 
 
 def mi_request(url: str, usr: str, pwd: str) -> requests.models.Response:
@@ -48,8 +59,7 @@ def mi_request(url: str, usr: str, pwd: str) -> requests.models.Response:
     :param url - The complete url with parameters.
     :param port - The host port
     :param usr - The user name
-    :param pwd - The user password
-'''
+    :param pwd - The user password'''
     with requests.get(url, verify=False, auth=HTTPBasicAuth(usr, pwd)) as request:
         return request
 
